/*
 * segatex SELinux tool.
 *
 * Copyright (C) 2007-2014 Shintaro Fujiwara 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * */

#ifndef SEGATEXGETSEUSERBYNAME_H
#define SEGATEXGETSEUSERBYNAME_H

#include <QDialog>
#include <QLayout>
#include <QLabel> 
#include <QLineEdit> 
#include <QTextEdit>
#include <QHBoxLayout>
#include <QVBoxLayout>

#include <selinux/selinux.h>

class SegatexGetseuserbynameProcess;

class SegatexGetseuserbyname: public QDialog
{
	Q_OBJECT
public:
	SegatexGetseuserbyname(QWidget *parent = 0, const char *name = 0);
	SegatexGetseuserbynameProcess *segatex_getseuserbyname_process;
public slots:
signals:
protected:
private slots:
	void get_button_clicked();
private:
	QPushButton *getButton;
	QPushButton *closeButton;

	QVBoxLayout *mainLayout;
	QHBoxLayout *leftLayout;
	QHBoxLayout *rightLayout;

        QLabel *getseuserbynameLabel;
        QLabel *getseuserbynameLabel2;
        QLineEdit *getseuserbynameLineEdit;
        QString getseuserbynameLineEdit_str;
};

#endif
